# Table of Contents

- [choosing-technology-for-your-integration](<./choosing-technology-for-your-integration.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Choosing a Technology for Your Integration](<./Choosing-a-Technology-for-Your-Integration.md>)
  - [Overview](<./Choosing-a-Technology-for-Your-Integration/Overview.md>)
  - [Use Out-of-the-Box Integrations](<./Choosing-a-Technology-for-Your-Integration/Use-Out-of-the-Box-Integrations.md>)
  - [Integrate Using the GraphQL API, REST APIs, and Webhooks](<./Choosing-a-Technology-for-Your-Integration/Integrate-Using-the-GraphQL-API-REST-APIs-and-Webhooks.md>)
  - [Build a Custom Integration Using the Integration API](<./Choosing-a-Technology-for-Your-Integration/Build-a-Custom-Integration-Using-the-Integration-API.md>)
